@@ -65,9 +65,11 @@ use owning_pointer::*;
 pub use storable::Storable;
 use syncutils::*;
 
+// TODO: When stable, use `std::ffi` instead of `core::ffi`
+// see: https://github.com/rust-lang/rust/commit/07ea143f96929ac7f0b7af0f025be48a472273e5
+use core::ffi::{c_int, c_uint};
 use std::cell::UnsafeCell;
 use std::collections::HashSet;
-use std::ffi::{c_int, c_uint};
 use std::ffi::{CStr, CString};
 use std::hash::{Hash, Hasher};
 use std::io;
